@@ -10,8 +10,6 @@ from ipywidgets import Image
 
 import hashlib
 
-import nose.tools as nt
-
 import pkgutil
 
 import tempfile
@@ -170,9 +168,5 @@ def get_hash_hex(byte_str):
     return m.hexdigest()
 
 
-def assert_equal_hash(byte_str, digest, msg=None):
-    kwargs = {}
-    if msg is not None:
-        kwargs['msg'] = msg
-
-    nt.eq_(get_hash_hex(byte_str), digest, **kwargs)
+def assert_equal_hash(byte_str, digest):
+    assert get_hash_hex(byte_str) == digest
